import request from '@/utils/request'

// 查询今日销售总金额，总升数
export function listSum(query) {
  return request({
    url: '/station/order/selectDaySources',
    method: 'get',
    params: query
  })
}

export function listOilType(query) {
  return request({
    url: '/station/order/selectOilTypeSources',
    method: 'get',
    params: query
  })
}
export function listViewData(query) {
  return request({
    url: '/station/order/selectOverViewData',
    method: 'get',
    params: query
  })
}

// 查询订单支付详细
export function getOrder(orderId) {
  return request({
    url: '/station/order/' + orderId,
    method: 'get'
  })
}

export function listDayReport(query) {
  return request({
    url: '/station/order/selectDayReport',
    method: 'get',
    params: query
  })
}
export function selectDayReportDetail(query) {
  return request({
    url: '/station/order/selectDayReportDetail',
    method: 'get',
    params: query
  })
}
export function getDetails(query) {
  return request({
    url: '/station/order/dayOilTypeSources',
    method: 'get',
    params: query
  })
}
export function listQydata92(query) {
  return request({
    url: '/station/order/listQydata92',
    method: 'get',
    params: query
  })
}
export function listQydata95(query) {
  return request({
    url: '/station/order/listQydata95',
    method: 'get',
    params: query
  })
}
export function listQydata98(query) {
  return request({
    url: '/station/order/listQydata98',
    method: 'get',
    params: query
  })
}
export function listQydata0(query) {
  return request({
    url: '/station/order/listQydata0',
    method: 'get',
    params: query
  })
}
export function listQydata10(query) {
  return request({
    url: '/station/order/listQydata10',
    method: 'get',
    params: query
  })
}
export function listQydata20(query) {
  return request({
    url: '/station/order/listQydata20',
    method: 'get',
    params: query
  })
}
export function listXdata(query) {
  return request({
    url: '/station/order/listXdata',
    method: 'get',
    params: query
  })
}
export function listCZXFData(query) {
  return request({
    url: '/customer/record/listCZXFData',
    method: 'get',
    params: query
  })
}

export function listHYData(query) {
  return request({
    url: '/customer/card/listHYData',
    method: 'get',
    params: query
  })
}
export function listJRHYData(query) {
  return request({
    url: '/customer/card/listJRHYData',
    method: 'get',
    params: query
  })
}

